# BiolinkML representation generators

* [contextgen.py]() - generate a JSON-LD @context block (see: [contextgen help](../../tests/test_scripts/output/gencontext/help))
* [csvgen.py]() - generate a csv summary (see: [csvgen help](../../tests/test_scripts/output/gencsv/help))
* [dotgen.py]() - generate graphviz representation (see: [dotgen help](../../tests/test_scripts/output/gengraphviz/help))
* [golrgen.py]() - generate a GOLR(?) representation (see: [golrgen help](../../tests/test_scripts/output/genglor/help))
* [graphqlgen.py]() - generate a graphql representation (see: [graphql help](../../tests/test_scripts/output/gengraphql/help))
* [jsonschemagen.py]() - generate JSON Schema representation (see: [jsonschmeagen help](../../tests/test_scripts/output/genjsonschema/help))
* [markdowngen.py]() - generate markdown documentation of the model (see: [markdowngen help](../../tests/test_scripts/output/genmarkdown/help))
* [ontolgen.py]() - generate an OWL representation (see: [ontolgen help](../../tests/test_scripts/output/genowl/help))
* [protogen.py]() - generate a proto(?) representation (see: [protogen help](../../tests/test_scripts/output/genproto/help))
* [pythongen.py]() - generate python classes for a model (see: [pythongen help](../../tests/test_scripts/output/genpython/help))
* [shexgen.py]() - generate a ShEx model representation (see: [shexgen help](../../tests/test_scripts/output/genshex/help))
* [yuml.py]() - generate a UML representation via [YUML](https://yuml.me/) (see: [yumlgen help](../../tests/test_scripts/output/genuml/help))





